==> qtsensors-opensource-src_5.2.1+dfsg.orig.tar.xz: qtsensors-opensource-src-5.2.1/src/plugins/sensors/android/src/androidaccelerometer.h <==
/****************************************************************************
**
** Copyright (C) 2013 BogDan Vatra <bogdan@kde.org>
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef ANDROIDACCELEROMETER_H
#define ANDROIDACCELEROMETER_H
#include <qaccelerometer.h>

#include "androidcommonsensor.h"

class AndroidAccelerometer : public AndroidCommonSensor<QAccelerometerReading>
{
public:
    AndroidAccelerometer(AndroidSensors::AndroidSensorType type, QSensor *sensor);

private:
    void onAccuracyChanged(jint accuracy) Q_DECL_OVERRIDE;
    void onSensorChanged(jlong timestamp, const jfloat *values, uint size) Q_DECL_OVERRIDE;

};

#endif // ANDROIDACCELEROMETER_H

==> qtsensors-opensource-src_5.3.0+dfsg.orig.tar.xz: qtsensors-opensource-src-5.3.0/src/plugins/sensors/android/src/androidaccelerometer.h <==
/****************************************************************************
**
** Copyright (C) 2013 BogDan Vatra <bogdan@kde.org>
** Contact: http://www.qt-project.org/legal
**
** This file is part of the QtSensors module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef ANDROIDACCELEROMETER_H
#define ANDROIDACCELEROMETER_H
#include <qaccelerometer.h>

#include "androidcommonsensor.h"

class AndroidAccelerometer : public AndroidCommonSensor<QAccelerometerReading>
{
    Q_OBJECT

public:
    AndroidAccelerometer(AndroidSensors::AndroidSensorType type, QSensor *sensor);
    static AndroidSensors::AndroidSensorType modeToSensor(QAccelerometer::AccelerationMode mode);
private:
    void onAccuracyChanged(jint accuracy) Q_DECL_OVERRIDE;
    void onSensorChanged(jlong timestamp, const jfloat *values, uint size) Q_DECL_OVERRIDE;

private Q_SLOTS:
    void applyAccelerationMode();

};

#endif // ANDROIDACCELEROMETER_H
